==> blesta-4.12.3.zip: blesta/components/invoice_templates/default_invoice/language/en_us/default_invoice.php <==
<?php
$lang['DefaultInvoice.name'] = 'Default';
$lang['DefaultInvoice.page_of'] = 'Page %1$s of %2$s'; // %1$s is the current page number, %2$s is the total number of pages
$lang['DefaultInvoice.terms_heading'] = 'Terms';
$lang['DefaultInvoice.type_active'] = 'INVOICE';
$lang['DefaultInvoice.type_draft'] = 'INVOICE - DRAFT';
$lang['DefaultInvoice.type_void'] = 'INVOICE - VOID';
$lang['DefaultInvoice.type_proforma'] = 'PRO FORMA INVOICE';
$lang['DefaultInvoice.invoice_id_code'] = 'Invoice Number:';
$lang['DefaultInvoice.proforma_id_code'] = 'Pro Forma Number:';
$lang['DefaultInvoice.draft_id_code'] = 'Draft Number:';
$lang['DefaultInvoice.client_id_code'] = 'Customer Number:';
$lang['DefaultInvoice.tax_id'] = 'Tax ID/VATIN:';
$lang['DefaultInvoice.client_tax_id'] = 'Customer Tax ID/VATIN:';
$lang['DefaultInvoice.date_billed'] = 'Invoice Date:';
$lang['DefaultInvoice.date_due'] = 'Due Date:';
$lang['DefaultInvoice.notes_heading'] = 'Notes';
$lang['DefaultInvoice.subtotal_heading'] = 'Subtotal';
$lang['DefaultInvoice.tax_heading'] = '%1$s (%2$s%%)'; // %1$s is the tax name, %2$s is the tax rate, %% escapes the percent (%) sign so it can be displayed
$lang['DefaultInvoice.total_heading'] = 'Total';
$lang['DefaultInvoice.lines_description'] = 'Description';
$lang['DefaultInvoice.lines_quantity'] = 'Quantity';
$lang['DefaultInvoice.lines_unit_price'] = 'Unit Price';
$lang['DefaultInvoice.lines_cost'] = 'Cost';
$lang['DefaultInvoice.watermark_paid'] = 'PAID';
$lang['DefaultInvoice.payments_heading'] = 'Payments';
$lang['DefaultInvoice.payments_applied_date'] = 'Date Applied';
$lang['DefaultInvoice.payments_type_name'] = 'Type';
$lang['DefaultInvoice.payments_transaction_id'] = 'Transaction Number';
$lang['DefaultInvoice.payments_applied_amount'] = 'Amount Applied';
$lang['DefaultInvoice.balance_heading'] = 'Balance';

==> blesta-5.0.0-5.0.4.zip: blesta/components/invoice_templates/default_invoice/language/en_us/default_invoice.php <==
<?php
$lang['DefaultInvoice.name'] = 'Default';
$lang['DefaultInvoice.page_of'] = 'Page %1$s of %2$s'; // %1$s is the current page number, %2$s is the total number of pages
$lang['DefaultInvoice.terms_heading'] = 'Terms';
$lang['DefaultInvoice.type_active'] = 'INVOICE';
$lang['DefaultInvoice.type_draft'] = 'INVOICE - DRAFT';
$lang['DefaultInvoice.type_void'] = 'INVOICE - VOID';
$lang['DefaultInvoice.type_proforma'] = 'PRO FORMA INVOICE';
$lang['DefaultInvoice.invoice_id_code'] = 'Invoice Number:';
$lang['DefaultInvoice.proforma_id_code'] = 'Pro Forma Number:';
$lang['DefaultInvoice.draft_id_code'] = 'Draft Number:';
$lang['DefaultInvoice.client_id_code'] = 'Customer Number:';
$lang['DefaultInvoice.tax_id'] = 'Tax ID/VATIN:';
$lang['DefaultInvoice.client_tax_id'] = 'Customer Tax ID/VATIN:';
$lang['DefaultInvoice.date_billed'] = 'Invoice Date:';
$lang['DefaultInvoice.date_due'] = 'Due Date:';
$lang['DefaultInvoice.notes_heading'] = 'Notes';
$lang['DefaultInvoice.subtotal_heading'] = 'Subtotal';
$lang['DefaultInvoice.tax_note_reverse_charge'] = 'The VAT Reverse Charge Mechanism is used. The tax liability transfers to the purchaser.';
$lang['DefaultInvoice.total_heading'] = 'Total';
$lang['DefaultInvoice.lines_description'] = 'Description';
$lang['DefaultInvoice.lines_quantity'] = 'Quantity';
$lang['DefaultInvoice.lines_unit_price'] = 'Unit Price';
$lang['DefaultInvoice.lines_cost'] = 'Cost';
$lang['DefaultInvoice.watermark_paid'] = 'PAID';
$lang['DefaultInvoice.payments_heading'] = 'Payments';
$lang['DefaultInvoice.payments_applied_date'] = 'Date Applied';
$lang['DefaultInvoice.payments_type_name'] = 'Type';
$lang['DefaultInvoice.payments_transaction_id'] = 'Transaction Number';
$lang['DefaultInvoice.payments_applied_amount'] = 'Amount Applied';
$lang['DefaultInvoice.balance_heading'] = 'Balance';
